@@ -1,5 +1,5 @@
 import numpy as np
-import pyfits as py
+from astropy.io import fits
 
 
 
@@ -9,7 +9,7 @@ def ellipse_to_reg( catalogue_name, regName='ellipse.reg' ):
     '''
 
 
-    catalogue = py.open( catalogue_name )[1].data
+    catalogue = fits.open( catalogue_name )[1].data
 
 
     regionFile = open( regName, 'w')
