@@ -3,15 +3,18 @@ return the HST filter of the input image
 '''
 
 from astropy.io import fits
+import json
 
-def getHSTfilter( infile, jwst=False ):
+def getHSTfilter( params ):
     '''
     Take the input infile and get the filter name
     '''
+    
+    header = fits.open( params['FILENAME'] )[0].header
 
-    header = fits.open( infile )[0].header
+    if params['jwst']:
+        print(("Using filter %s for image %s" % (header['FILTER'],  params['FILENAME'])))
 
-    if jwst:
         return header['FILTER']
 
     if 'CLEAR' in header['FILTER1']:
@@ -19,5 +22,5 @@ def getHSTfilter( infile, jwst=False ):
     else:
         hst_filter = header['FILTER1']
         
-    print(("Using filter %s for image %s" % (hst_filter, infile)))
+    print(("Using filter %s for image %s" % (hst_filter,  params['FILENAME'])))
     return hst_filter
